import pysegul

import os

def test_sequence_extract(tmp_path):
    input_dir = 'tests/align-data'
    input_format = 'nexus'
    datatype = 'dna'
    output_format = 'fasta'
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    extract = pysegul.SequenceExtraction(
        input_format,  
        datatype, 
        output_dir, 
        output_format,
        )
    extract.input_dir = input_dir
    extract.extract_regex("(?i)^(abce)")
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = os.listdir(output_path)
    assert len(results) == 2
    # Clean up output directory before the next test
    for i in results:
        os.remove(output_path.joinpath(i))
    extract.extract_id_list(['ABCD'])
    assert output_path.exists()
    results = os.listdir(output_path)
    assert len(results) == 4


import pysegul

from os import listdir

input_format = 'nexus'
datatype = 'dna'
output_format = 'fasta'
partition_format = 'raxml'
prefix = 'concatenated'

def test_align_concatenation(tmp_path):
    input_dir = 'tests/align-data'
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    concat = pysegul.AlignmentConcatenation(
        input_format,  
        datatype, 
        output_dir, 
        output_format, 
        partition_format, 
        prefix
        )
    concat.from_dir(input_dir)
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = listdir(output_path)
    assert len(results) == 2

def test_concat_alignments_from_list(tmp_path):
    files: list = ['tests/align-data/gene_1.nex', 'tests/align-data/gene_2.nex']
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    concat = pysegul.AlignmentConcatenation(
        input_format,  
        datatype, 
        output_dir, 
        output_format, 
        partition_format, 
        prefix
        )
    concat.from_files(files)
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = listdir(output_path)
    assert len(results) == 2


import pysegul


from os import listdir

def test_align_split(tmp_path):
    input_alignment = 'tests/split-data/split-data.nex'
    input_format = 'nexus'
    datatype = 'dna'
    partition_format = 'nexus'
    output_format = 'fasta'
    check_partition = True
    input_partition = 'tests/split-data/split-data_partition.nex'
    output_dir = str(tmp_path.joinpath('results'))
    split = pysegul.AlignmentSplitting(
        input_alignment,
        input_format,  
        datatype, 
        output_dir, 
        output_format,
        partition_format,
        check_partition,
        input_partition = input_partition
        )
    split.split()
    assert tmp_path.joinpath('results').exists()
    # Check if the output directory contains the expected files
    results = listdir(output_dir)
    assert len(results) == 4


import pysegul

from os import listdir

def test_read_summary(tmp_path):
    input_dir = 'tests/raw-data'
    input_format = 'auto'
    summary_mode = 'default'
    prefix = 'read_summary'
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    summary = pysegul.ReadSummary(
        input_format,  
        summary_mode,
        output_dir,
        prefix
        )
    summary.from_dir(input_dir)
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = listdir(output_path)
    assert len(results) == 1


import pysegul

from os import listdir

def test_align_filter(tmp_path):
    input_dir = 'tests/align-data'
    input_format = 'nexus'
    datatype = 'dna'
    output_format = 'nexus'
    is_concat = False
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    filter = pysegul.AlignmentFiltering(
        input_format,  
        datatype, 
        output_dir, 
        output_format,
        is_concat
        )
    filter.input_dir = input_dir
    filter.minimal_length(8)
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = listdir(output_path)
    assert len(results) == 1


import pysegul

from os import listdir

def test_partition_convert(tmp_path):
    input_paths = [
        'tests/partition-data/partition_codon.txt', 
        'tests/partition-data/partition.txt'
        ]
    input_format = 'raxml'
    output_format = 'nexus'
    datatype = 'dna'
    check_partition = True
    output_dir = str(tmp_path.joinpath('results'))
    convert = pysegul.PartitionConversion(
        input_format,
        datatype,
        output_dir,
        output_format,
        check_partition
        )
    convert.from_files(input_paths)
    assert tmp_path.joinpath('results').exists()
    # Check if the output directory contains the expected files
    results = listdir(output_dir)
    assert len(results) == 2
    assert 'partition_codon_partition.nex' in results


import pysegul

from os import listdir

def test_align_summary(tmp_path):
    input_dir = 'tests/align-data'
    input_format = 'nexus'
    datatype = 'dna'
    completeness_interval = 5
    prefix = 'concatenated'
    output_path = tmp_path.joinpath('results')
    output_dir = str(output_path)
    concat = pysegul.AlignmentSummary(
        input_format,  
        datatype, 
        output_dir,
        completeness_interval,
        prefix
        )
    concat.from_dir(input_dir)
    assert output_path.exists()
    # Check if the output directory contains the expected files
    results = listdir(output_path)
    assert len(results) == 3